@@ -3,6 +3,8 @@ import os
 import logging
 import requests
 import json
+from urlparse import urljoin
+
 from .utils import retry
 from .errors import GoogleApiError
 
@@ -197,7 +199,7 @@ class APIRequest(object):
 
         resp = self._api_request(
             'POST',
-            ''.join([self._API_URL, '/upload/drive/v2/files']),
+            urljoin(self._API_URL, '/upload/drive/v2/files'),
             params={'uploadType': 'multipart'},
             headers=headers,
             data=body,
@@ -260,7 +262,7 @@ class APIRequest(object):
         req = requests.Session()
         resp = self._api_request(
             'POST',
-            ''.join([self._API_URL, '/upload/drive/v2/files']),
+            urljoin(self._API_URL, '/upload/drive/v2/files'),
             session=req,
             params={'uploadType': 'resumable'},
             headers=self._default_headers,
@@ -397,8 +399,8 @@ class APIRequest(object):
                 data = None
             resp = self._api_request(
                 'PUT',
-                ''.join(
-                    [self._API_URL, '/upload/drive/v2/files/', file_id]),
+                urljoin(self._API_URL,
+                        '/upload/drive/v2/files/{0}'.format(file_id)),
                 session=req,
                 params={'uploadType': 'resumable'},
                 headers=headers,
@@ -532,8 +534,6 @@ class APIRequest(object):
         :rtype:
             `tuple`
         """
-        from urlparse import urljoin
-
         if resource.startswith('http'):
             url = resource
         else:
